package javax.rmi.ssl;

import javax.net.ssl.SSLSocketFactory;
import java.io.IOException;
import java.util.StringTokenizer;
import javax.net.ssl.SSLSocket;
import java.net.Socket;
import javax.net.SocketFactory;
import java.io.Serializable;
import java.rmi.server.RMIClientSocketFactory;

public class SslRMIClientSocketFactory implements RMIClientSocketFactory, Serializable
{
    private static SocketFactory defaultSocketFactory;
    private static final long serialVersionUID = -8310631444933958385L;
    
    public SslRMIClientSocketFactory() {
    }
    
    @Override
    public Socket createSocket(String s, int n) throws IOException {
        SSLSocket sslSocket = (SSLSocket)getDefaultClientSocketFactory().createSocket(s, n);
        String property = System.getProperty("javax.rmi.ssl.client.enabledCipherSuites");
        if (property != null) {
            StringTokenizer stringTokenizer = new StringTokenizer(property, ",");
            int countTokens = stringTokenizer.countTokens();
            String[] enabledCipherSuites = new String[countTokens];
            for (int i = 0; i < countTokens; ++i) {
                enabledCipherSuites[i] = stringTokenizer.nextToken();
            }
            try {
                sslSocket.setEnabledCipherSuites(enabledCipherSuites);
            }
            catch (IllegalArgumentException cause) {
                throw (IOException)new IOException(cause.getMessage()).initCause(cause);
            }
        }
        String property2 = System.getProperty("javax.rmi.ssl.client.enabledProtocols");
        if (property2 != null) {
            StringTokenizer o = new StringTokenizer(property2, ",");
            int countTokens2 = o.countTokens();
            String[] enabledProtocols = new String[countTokens2];
            for (int j = 0; j < countTokens2; ++j) {
                enabledProtocols[j] = o.nextToken();
            }
            try {
                sslSocket.setEnabledProtocols(enabledProtocols);
            }
            catch (IllegalArgumentException cause2) {
                throw (IOException)new IOException(cause2.getMessage()).initCause(cause2);
            }
        }
        return sslSocket;
    }
    
    @Override
    public boolean equals(Object o) {
        return o != null && (o == this || this.getClass().equals(o.getClass()));
    }
    
    @Override
    public int hashCode() {
        return this.getClass().hashCode();
    }
    
    private static synchronized SocketFactory getDefaultClientSocketFactory() {
        if (SslRMIClientSocketFactory.defaultSocketFactory == null) {
            SslRMIClientSocketFactory.defaultSocketFactory = SSLSocketFactory.getDefault();
        }
        return SslRMIClientSocketFactory.defaultSocketFactory;
    }
    
    static {
        SslRMIClientSocketFactory.defaultSocketFactory = null;
    }
}
